@@ -5,7 +5,7 @@ use warnings;
 use Carp qw(croak);
 use Scalar::Util qw(weaken refaddr);
 
-our $VERSION = '0.25';
+our $VERSION = '0.28';
 
 sub new {
     my $proto = shift;
@@ -199,7 +199,7 @@ use Carp qw(carp croak confess);
 use Scalar::Util qw(weaken refaddr);
 use XML::SAX;
 
-our $VERSION          = '0.25';
+our $VERSION          = '0.28';
 our $DEFAULT_ENCODING = 'UTF-8';
 our $ENCODING         = undef;
 our $Indent           = '  ';
@@ -891,12 +891,13 @@ sub _fast_string {
 sub _escapeXML {
     my $data = $_[0];
     return '' unless(defined($data));
-    if ($data =~ /[\&\<\>\"(__AMP__)]/o) {
+    if ($data =~ /[\&\<\>\"(__AMP__)\']/o) {
         $data =~ s/\&(?!\w+\;)/\&amp\;/go;
         $data =~ s/\</\&lt\;/go;
         $data =~ s/\>/\&gt\;/go;
         $data =~ s/\"/\&quot\;/go;
         $data =~ s/__AMP__/\&/go;
+        $data =~ s/\'/\&apos\;/go;
     }
     return $data;
 }
@@ -918,7 +919,7 @@ XML::API - Perl extension for writing XML
 
 =head1 VERSION
 
-0.24
+0.28 (2015-11-30)
 
 =head1 SYNOPSIS
 
@@ -1437,7 +1438,7 @@ A small request: if you use this module I would appreciate hearing about it.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004-2007 Mark Lawrence <nomad@null.net>
+Copyright (C) 2004-2010 Mark Lawrence <nomad@null.net>
 
 =head1 LICENSE
 
