@@ -4,7 +4,7 @@ use warnings;
 use Carp qw(croak);
 use overload '""' => \&content;
 
-our $VERSION = '0.25';
+our $VERSION = '0.28';
 
 sub new {
     my $proto = shift;
@@ -39,6 +39,10 @@ __END__
 
 XML::API::Cache - Cached version of an XML::API object
 
+=head1 VERSION
+
+0.28 (2015-11-30)
+
 =head1 SYNOPSIS
 
   use XML::API::Cache;
@@ -89,7 +93,7 @@ Mark Lawrence E<lt>nomad@null.net<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 Mark Lawrence <nomad@null.net>
+Copyright (C) 2008,2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
