@@ -1,19 +1,9 @@
 package XML::API::XHTML;
-# ----------------------------------------------------------------------
-# Copyright (C) 2004 Mark Lawrence <nomad@null.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-# ----------------------------------------------------------------------
-# Derivative of XML::API for XHTML 
-# ----------------------------------------------------------------------
 use strict;
 use warnings;
 use base qw(XML::API);
 
-our $VERSION = '0.25';
+our $VERSION = '0.28';
 
 use constant DOCTYPE => qq{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">};
 
@@ -54,6 +44,10 @@ __END__
 
 XML::API::XHTML - XHTML generation through an object API
 
+=head1 VERSION
+
+0.28 (2015-11-30)
+
 =head1 SYNOPSIS
 
 As a simple example the following perl code:
@@ -199,7 +193,7 @@ Mark Lawrence E<lt>nomad@null.net<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004 Mark Lawrence <nomad@null.net>
+Copyright (C) 2004,2015 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
